==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/expression/impl/AnySetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.Any;
import io.ciera.tool.sql.architecture.expression.AnySet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.List;


public class AnySetImpl extends InstanceSet<AnySet,Any> implements AnySet {

    // attributes
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Any any : this ) any.setStatement_number( ref_statement_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Any any : this ) any.setParent_package( ref_parent_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( Any any : this ) any.setExpression_number( ref_expression_number );
    }
    @Override
    public void setAny_expression_number( String ref_any_expression_number ) throws XtumlException {
        for ( Any any : this ) any.setAny_expression_number( ref_any_expression_number );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Any any : this ) any.setBlock_number( ref_block_number );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Any any : this ) any.setParent_name( ref_parent_name );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( Any any : this ) any.setBody_name( ref_body_name );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Any any : this ) expressionset.add( any.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R783_gets_an_arbitrary_element_from_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Any any : this ) expressionset.add( any.R783_gets_an_arbitrary_element_from_Expression() );
        return expressionset;
    }


    @Override
    public Any nullElement() {
        return AnyImpl.EMPTY_ANY;
    }

    @Override
    public AnySet emptySet() {
      return new AnySetImpl();
    }

    @Override
    public AnySet value() {
        return this;
    }

    @Override
    public List<Any> elements() {
        return Arrays.asList(toArray(new Any[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/expression/impl/AnySetImpl.java <==
package io.ciera.tool.sql.architecture.expression.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.expression.Any;
import io.ciera.tool.sql.architecture.expression.AnySet;
import io.ciera.tool.sql.architecture.expression.ExpressionSet;
import io.ciera.tool.sql.architecture.expression.impl.ExpressionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AnySetImpl extends InstanceSet<AnySet,Any> implements AnySet {

    public AnySetImpl() {
    }

    public AnySetImpl(Comparator<? super Any> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_number( String ref_statement_number ) throws XtumlException {
        for ( Any any : this ) any.setStatement_number( ref_statement_number );
    }
    @Override
    public void setBlock_number( String ref_block_number ) throws XtumlException {
        for ( Any any : this ) any.setBlock_number( ref_block_number );
    }
    @Override
    public void setBody_name( String ref_body_name ) throws XtumlException {
        for ( Any any : this ) any.setBody_name( ref_body_name );
    }
    @Override
    public void setParent_name( String ref_parent_name ) throws XtumlException {
        for ( Any any : this ) any.setParent_name( ref_parent_name );
    }
    @Override
    public void setAny_expression_number( String ref_any_expression_number ) throws XtumlException {
        for ( Any any : this ) any.setAny_expression_number( ref_any_expression_number );
    }
    @Override
    public void setParent_package( String ref_parent_package ) throws XtumlException {
        for ( Any any : this ) any.setParent_package( ref_parent_package );
    }
    @Override
    public void setExpression_number( String ref_expression_number ) throws XtumlException {
        for ( Any any : this ) any.setExpression_number( ref_expression_number );
    }


    // selections
    @Override
    public ExpressionSet R776_is_a_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Any any : this ) expressionset.add( any.R776_is_a_Expression() );
        return expressionset;
    }
    @Override
    public ExpressionSet R783_gets_an_arbitrary_element_from_Expression() throws XtumlException {
        ExpressionSet expressionset = new ExpressionSetImpl();
        for ( Any any : this ) expressionset.add( any.R783_gets_an_arbitrary_element_from_Expression() );
        return expressionset;
    }


    @Override
    public Any nullElement() {
        return AnyImpl.EMPTY_ANY;
    }

    @Override
    public AnySet emptySet() {
      return new AnySetImpl();
    }

    @Override
    public AnySet emptySet(Comparator<? super Any> comp) {
      return new AnySetImpl(comp);
    }

    @Override
    public AnySet value() {
        return this;
    }

    @Override
    public List<Any> elements() {
        return Arrays.asList(toArray(new Any[0]));
    }

}
